@@ -21,6 +21,9 @@ FIELD_TYPE_MAP = {
     "dict": "DictField",
     "oid": "ObjectIdField",
     "object_id": "ObjectIdField",
+    "datetime": "DatetimeField",
+    "date": "DatetimeField",
+    "ts": "DatetimeField",
 }
 
 
@@ -82,7 +85,7 @@ def run_create(args):
         os.chdir(dirname)
         venv.create(args.venv, with_pip=True)
         python_path = os.path.join(os.curdir, "venv/bin/pip3")
-        p = Popen([python_path, 'install', '-r', 'requirements.txt'])
+        p = Popen([python_path, "install", "-r", "requirements.txt"])
         p.wait()
         os.chmod("glass.py", 0o755)
     finally:
@@ -92,7 +95,9 @@ def run_create(args):
 def run_new_model(args):
     project_name = find_project_name()
     if project_name is None:
-        raise RuntimeError("project name is not detected. are you inside your project folder?")
+        raise RuntimeError(
+            "project name is not detected. are you inside your project folder?"
+        )
 
     model_name = args.model_name[0]
     class_name = ""
@@ -108,7 +113,7 @@ def run_new_model(args):
         field_desc = field_desc[0]
 
         if field_type not in FIELD_TYPE_MAP:
-            raise TypeError(f"invalid field type \"{field_type}\"")
+            raise TypeError(f'invalid field type "{field_type}"')
         fields.append((field_desc, FIELD_TYPE_MAP[field_type]))
     model_imports = ", ".join({fd[1] for fd in fields})
     tmplfilename = os.path.join(glasskit_directory(), "unit_templates/model.py.tmpl")
@@ -118,18 +123,24 @@ def run_new_model(args):
     model_filename = os.path.join(project_name, f"models/{model_name}.py")
     os.makedirs(os.path.dirname(model_filename), exist_ok=True)
     with open(model_filename, "w") as modelf:
-        modelf.write(tmpl.render({
-            "classname": class_name,
-            "model_imports": model_imports,
-            "fields": fields
-        }))
+        modelf.write(
+            tmpl.render(
+                {
+                    "classname": class_name,
+                    "model_imports": model_imports,
+                    "fields": fields,
+                }
+            )
+        )
     print(f"File {model_filename} created")
 
 
 def run_new_controller(args):
     project_name = find_project_name()
     if project_name is None:
-        raise RuntimeError("project name is not detected. are you inside your project folder?")
+        raise RuntimeError(
+            "project name is not detected. are you inside your project folder?"
+        )
 
     cls_tokens = args.ctrl_class.split(".")
     cls_module_path = ".".join(cls_tokens[:-1])
@@ -140,20 +151,19 @@ def run_new_controller(args):
     ctrl_name = path_tokens[-1]
 
     ctrl_filename = os.path.join(
-        project_name,
-        "controllers",
-        ctrl_path,
-        f"{ctrl_name}.py"
+        project_name, "controllers", ctrl_path, f"{ctrl_name}.py"
     )
 
     context = {
         "cls_module_path": cls_module_path,
         "cls_name": cls_name,
         "ctrl_name": ctrl_name,
-        "require_auth": not args.disable_auth
+        "require_auth": not args.disable_auth,
     }
 
-    tmplfilename = os.path.join(glasskit_directory(), "unit_templates/controller.py.tmpl")
+    tmplfilename = os.path.join(
+        glasskit_directory(), "unit_templates/controller.py.tmpl"
+    )
     with open(tmplfilename) as tmplfile:
         tmpl = jinja2.Template(tmplfile.read())
 
@@ -163,6 +173,12 @@ def run_new_controller(args):
 
 
 def run_new_task(args):
+    project_name = find_project_name()
+    if project_name is None:
+        raise RuntimeError(
+            "project name is not detected. are you inside your project folder?"
+        )
+
     class_name = args.class_name[0]
     fields = args.fields
     create_args_list = ", ".join(["cls"] + fields)
@@ -180,37 +196,72 @@ def run_new_task(args):
         "create_args_list": create_args_list,
     }
 
-    print(tmpl.render(**context))
+    task_filename = snake_case(class_name).lower() + ".py"
+    task_filename = os.path.join(project_name, "tasks", task_filename)
+
+    with open(task_filename, "w") as outfile:
+        outfile.write(tmpl.render(**context))
 
 
 def main():
     parser = argparse.ArgumentParser(prog="glasskit")
-    subparsers = parser.add_subparsers(dest="command", required=True, help="sub-command help")
+    subparsers = parser.add_subparsers(
+        dest="command", required=True, help="sub-command help"
+    )
 
-    parser_create = subparsers.add_parser("create", help="bootstrap a new glasskit project")
-    parser_create.add_argument("project_name", nargs=1, type=str, help="project name to create")
-    parser_create.add_argument("--venv", "-v", type=str, default="venv", help="venv directory name")
+    parser_create = subparsers.add_parser(
+        "create", help="bootstrap a new glasskit project"
+    )
+    parser_create.add_argument(
+        "project_name", nargs=1, type=str, help="project name to create"
+    )
+    parser_create.add_argument(
+        "--venv", "-v", type=str, default="venv", help="venv directory name"
+    )
 
-    parser_new = subparsers.add_parser("new", help="create a new unit, i.e. model, controller, task")
-    parser_new_subparsers = parser_new.add_subparsers(dest="unit", required=True, help="unit-type help")
-    new_model_parser = parser_new_subparsers.add_parser("model", help="create a new model")
+    parser_new = subparsers.add_parser(
+        "new", help="create a new unit, i.e. model, controller, task"
+    )
+    parser_new_subparsers = parser_new.add_subparsers(
+        dest="unit", required=True, help="unit-type help"
+    )
+    new_model_parser = parser_new_subparsers.add_parser(
+        "model", help="create a new model"
+    )
 
     new_model_parser.add_argument("model_name", nargs=1, type=str, help="model_name")
-    new_model_parser.add_argument("fields", nargs="*", type=str, help="field descriptors: field1:any field2 "
-                                                                      "field3:string "
-                                                                      "field4:list etc...")
+    new_model_parser.add_argument(
+        "fields",
+        nargs="*",
+        type=str,
+        help="field descriptors: field1:any field2 "
+        "field3:string "
+        "field4:list etc...",
+    )
 
     new_task_parser = parser_new_subparsers.add_parser("task", help="create a new task")
-    new_task_parser.add_argument("class_name", nargs=1, type=str, help="name of the task class")
+    new_task_parser.add_argument(
+        "class_name", nargs=1, type=str, help="name of the task class"
+    )
     new_task_parser.add_argument("fields", nargs="*", type=str, help="task fields list")
 
-    new_controller_parser = parser_new_subparsers.add_parser("controller", help="create a new controller")
-    new_controller_parser.add_argument("ctrl_path", nargs=1, type=str, help="controller prefix path, i.e. api/v1/users")
-    new_controller_parser.add_argument("--disable-auth", "-d", action="store_true",
-                                       help="disable auth requirement")
-    new_controller_parser.add_argument("--class", "-c", dest="ctrl_class", type=str,
-                                       default="glasskit.controller.Controller",
-                                       help="override default controller class")
+    new_controller_parser = parser_new_subparsers.add_parser(
+        "controller", help="create a new controller"
+    )
+    new_controller_parser.add_argument(
+        "ctrl_path", nargs=1, type=str, help="controller prefix path, i.e. api/v1/users"
+    )
+    new_controller_parser.add_argument(
+        "--disable-auth", "-d", action="store_true", help="disable auth requirement"
+    )
+    new_controller_parser.add_argument(
+        "--class",
+        "-c",
+        dest="ctrl_class",
+        type=str,
+        default="glasskit.controller.Controller",
+        help="override default controller class",
+    )
     args = parser.parse_args()
 
     if args.command == "create":
